summaryrefslogtreecommitdiffstats
path: root/generic
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-12-04 11:02:32 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-12-04 11:02:32 (GMT)
commitcb5c9f4f89b6e7242ba07f84e278d35f202d7edd (patch)
tree96dc9dce0760840b34674d123d10a5d14ff148a7 /generic
parenteacedab36179d8cd74e4c302cd1614dea9d38c34 (diff)
parentc47a86166324a3e2efe9359c431bb93f7519847c (diff)
downloadtcl-cb5c9f4f89b6e7242ba07f84e278d35f202d7edd.zip
tcl-cb5c9f4f89b6e7242ba07f84e278d35f202d7edd.tar.gz
tcl-cb5c9f4f89b6e7242ba07f84e278d35f202d7edd.tar.bz2
Merge 8.7
Diffstat (limited to 'generic')
-rw-r--r--generic/tclBasic.c1
-rw-r--r--generic/tclCmdMZ.c50
-rw-r--r--generic/tclIOUtil.c4
-rw-r--r--generic/tclLoad.c4
-rw-r--r--generic/tclOO.c9
-rw-r--r--generic/tclOOStubLib.c9
-rw-r--r--generic/tclTest.c2
-rw-r--r--generic/tclTestProcBodyObj.c8
-rw-r--r--generic/tclZipfs.c2
-rw-r--r--generic/tclZlib.c5
10 files changed, 57 insertions, 37 deletions
diff --git a/generic/tclBasic.c b/generic/tclBasic.c
index e12381c..4ed8505 100644
--- a/generic/tclBasic.c
+++ b/generic/tclBasic.c
@@ -1132,6 +1132,7 @@ Tcl_CreateInterp(void)
*/
Tcl_PkgProvideEx(interp, "Tcl", TCL_PATCH_LEVEL, &tclStubs);
+ Tcl_PkgProvideEx(interp, "tcl", TCL_PATCH_LEVEL, &tclStubs);
if (TclTommath_Init(interp) != TCL_OK) {
Tcl_Panic("%s", Tcl_GetStringResult(interp));
diff --git a/generic/tclCmdMZ.c b/generic/tclCmdMZ.c
index 4ffe48b..4493b85 100644
--- a/generic/tclCmdMZ.c
+++ b/generic/tclCmdMZ.c
@@ -36,31 +36,31 @@ static int UniCharIsHexDigit(int character);
*/
const char tclDefaultTrimSet[] =
- "\x09\x0a\x0b\x0c\x0d " /* ASCII */
- "\xc0\x80" /* nul (U+0000) */
- "\xc2\x85" /* next line (U+0085) */
- "\xc2\xa0" /* non-breaking space (U+00a0) */
- "\xe1\x9a\x80" /* ogham space mark (U+1680) */
- "\xe1\xa0\x8e" /* mongolian vowel separator (U+180e) */
- "\xe2\x80\x80" /* en quad (U+2000) */
- "\xe2\x80\x81" /* em quad (U+2001) */
- "\xe2\x80\x82" /* en space (U+2002) */
- "\xe2\x80\x83" /* em space (U+2003) */
- "\xe2\x80\x84" /* three-per-em space (U+2004) */
- "\xe2\x80\x85" /* four-per-em space (U+2005) */
- "\xe2\x80\x86" /* six-per-em space (U+2006) */
- "\xe2\x80\x87" /* figure space (U+2007) */
- "\xe2\x80\x88" /* punctuation space (U+2008) */
- "\xe2\x80\x89" /* thin space (U+2009) */
- "\xe2\x80\x8a" /* hair space (U+200a) */
- "\xe2\x80\x8b" /* zero width space (U+200b) */
- "\xe2\x80\xa8" /* line separator (U+2028) */
- "\xe2\x80\xa9" /* paragraph separator (U+2029) */
- "\xe2\x80\xaf" /* narrow no-break space (U+202f) */
- "\xe2\x81\x9f" /* medium mathematical space (U+205f) */
- "\xe2\x81\xa0" /* word joiner (U+2060) */
- "\xe3\x80\x80" /* ideographic space (U+3000) */
- "\xef\xbb\xbf" /* zero width no-break space (U+feff) */
+ "\x09\x0A\x0B\x0C\x0D " /* ASCII */
+ "\xC0\x80" /* nul (U+0000) */
+ "\xC2\x85" /* next line (U+0085) */
+ "\xC2\xA0" /* non-breaking space (U+00a0) */
+ "\xE1\x9A\x80" /* ogham space mark (U+1680) */
+ "\xE1\xA0\x8E" /* mongolian vowel separator (U+180e) */
+ "\xE2\x80\x80" /* en quad (U+2000) */
+ "\xE2\x80\x81" /* em quad (U+2001) */
+ "\xE2\x80\x82" /* en space (U+2002) */
+ "\xE2\x80\x83" /* em space (U+2003) */
+ "\xE2\x80\x84" /* three-per-em space (U+2004) */
+ "\xE2\x80\x85" /* four-per-em space (U+2005) */
+ "\xE2\x80\x86" /* six-per-em space (U+2006) */
+ "\xE2\x80\x87" /* figure space (U+2007) */
+ "\xE2\x80\x88" /* punctuation space (U+2008) */
+ "\xE2\x80\x89" /* thin space (U+2009) */
+ "\xE2\x80\x8A" /* hair space (U+200a) */
+ "\xE2\x80\x8B" /* zero width space (U+200b) */
+ "\xE2\x80\xA8" /* line separator (U+2028) */
+ "\xE2\x80\xA9" /* paragraph separator (U+2029) */
+ "\xE2\x80\xAF" /* narrow no-break space (U+202f) */
+ "\xE2\x81\x9F" /* medium mathematical space (U+205f) */
+ "\xE2\x81\xA0" /* word joiner (U+2060) */
+ "\xE3\x80\x80" /* ideographic space (U+3000) */
+ "\xEF\xBB\xBF" /* zero width no-break space (U+feff) */
;
/*
diff --git a/generic/tclIOUtil.c b/generic/tclIOUtil.c
index 4cd2c6d..2fc439f 100644
--- a/generic/tclIOUtil.c
+++ b/generic/tclIOUtil.c
@@ -1757,7 +1757,7 @@ Tcl_FSEvalFileEx(
*/
if (Tcl_ReadChars(chan, objPtr, -1,
- memcmp(string, "\xef\xbb\xbf", 3)) == TCL_IO_FAILURE) {
+ memcmp(string, "\xEF\xBB\xBF", 3)) == TCL_IO_FAILURE) {
Tcl_CloseEx(interp, chan, 0);
Tcl_SetObjResult(interp, Tcl_ObjPrintf(
"couldn't read file \"%s\": %s",
@@ -1894,7 +1894,7 @@ TclNREvalFile(
*/
if (Tcl_ReadChars(chan, objPtr, -1,
- memcmp(string, "\xef\xbb\xbf", 3)) == TCL_IO_FAILURE) {
+ memcmp(string, "\xEF\xBB\xBF", 3)) == TCL_IO_FAILURE) {
Tcl_CloseEx(interp, chan, 0);
Tcl_SetObjResult(interp, Tcl_ObjPrintf(
"couldn't read file \"%s\": %s",
diff --git a/generic/tclLoad.c b/generic/tclLoad.c
index 5090493..af9fd12 100644
--- a/generic/tclLoad.c
+++ b/generic/tclLoad.c
@@ -331,6 +331,10 @@ Tcl_LoadObjCmd(
pkgGuess += 3;
}
#endif /* __CYGWIN__ */
+ if ((pkgGuess[0] == 't') && (pkgGuess[1] == 'c')
+ && (pkgGuess[2] == 'l')) {
+ pkgGuess += 3;
+ }
for (p = pkgGuess; *p != 0; p += offset) {
offset = TclUtfToUniChar(p, &ch);
if ((ch > 0x100)
diff --git a/generic/tclOO.c b/generic/tclOO.c
index 0f0cc96..5f1b816 100644
--- a/generic/tclOO.c
+++ b/generic/tclOO.c
@@ -138,7 +138,10 @@ static const Tcl_MethodType classConstructor = {
*/
static const char *initScript =
+#ifndef TCL_NO_DEPRECATED
"package ifneeded TclOO " TCLOO_PATCHLEVEL " {# Already present, OK?};"
+#endif
+"package ifneeded tcl::oo " TCLOO_PATCHLEVEL " {# Already present, OK?};"
"namespace eval ::oo { variable version " TCLOO_VERSION " };"
"namespace eval ::oo { variable patchlevel " TCLOO_PATCHLEVEL " };";
/* "tcl_findLibrary tcloo $oo::version $oo::version" */
@@ -257,7 +260,11 @@ TclOOInit(
return TCL_ERROR;
}
- return Tcl_PkgProvideEx(interp, "TclOO", TCLOO_PATCHLEVEL,
+#ifndef TCL_NO_DEPRECATED
+ Tcl_PkgProvideEx(interp, "TclOO", TCLOO_PATCHLEVEL,
+ (void *) &tclOOStubs);
+#endif
+ return Tcl_PkgProvideEx(interp, "tcl::oo", TCLOO_PATCHLEVEL,
(void *) &tclOOStubs);
}
diff --git a/generic/tclOOStubLib.c b/generic/tclOOStubLib.c
index a9fa212..221d99a 100644
--- a/generic/tclOOStubLib.c
+++ b/generic/tclOOStubLib.c
@@ -35,14 +35,19 @@ TclOOInitializeStubs(
const char *version)
{
int exact = 0;
- const char *packageName = "TclOO";
+ const char *packageName = "tcl::oo";
const char *errMsg = NULL;
TclOOStubs *stubsPtr = NULL;
const char *actualVersion = tclStubsPtr->tcl_PkgRequireEx(interp,
packageName, version, exact, &stubsPtr);
if (actualVersion == NULL) {
- return NULL;
+ packageName = "TclOO";
+ actualVersion = tclStubsPtr->tcl_PkgRequireEx(interp,
+ packageName, version, exact, &stubsPtr);
+ if (actualVersion == NULL) {
+ return NULL;
+ }
}
if (stubsPtr == NULL) {
errMsg = "missing stub table pointer";
diff --git a/generic/tclTest.c b/generic/tclTest.c
index d12868f..48c9163 100644
--- a/generic/tclTest.c
+++ b/generic/tclTest.c
@@ -460,7 +460,7 @@ Tcltest_Init(
}
/* TIP #268: Full patchlevel instead of just major.minor */
- if (Tcl_PkgProvideEx(interp, "Tcltest", TCL_PATCH_LEVEL, NULL) == TCL_ERROR) {
+ if (Tcl_PkgProvideEx(interp, "tcl::test", TCL_PATCH_LEVEL, NULL) == TCL_ERROR) {
return TCL_ERROR;
}
diff --git a/generic/tclZipfs.c b/generic/tclZipfs.c
index bc59f15..b6d5c96 100644
--- a/generic/tclZipfs.c
+++ b/generic/tclZipfs.c
@@ -4737,7 +4737,7 @@ TclZipfs_Init(
Tcl_NewStringObj("::tcl::zipfs::find", -1));
Tcl_CreateObjCommand(interp, "::tcl::zipfs::tcl_library_init",
ZipFSTclLibraryObjCmd, NULL, NULL);
- Tcl_PkgProvideEx(interp, "zipfs", "2.0", NULL);
+ Tcl_PkgProvideEx(interp, "tcl::zipfs", "2.0", NULL);
}
return TCL_OK;
#else /* !HAVE_ZLIB */
diff --git a/generic/tclZlib.c b/generic/tclZlib.c
index 154325a..b85cd77 100644
--- a/generic/tclZlib.c
+++ b/generic/tclZlib.c
@@ -3969,7 +3969,10 @@ TclZlibInit(
* Formally provide the package as a Tcl built-in.
*/
- return Tcl_PkgProvideEx(interp, "zlib", TCL_ZLIB_VERSION, NULL);
+#ifndef TCL_NO_DEPRECATED
+ Tcl_PkgProvideEx(interp, "zlib", TCL_ZLIB_VERSION, NULL);
+#endif
+ return Tcl_PkgProvideEx(interp, "tcl::zlib", TCL_ZLIB_VERSION, NULL);
}
/*
diff --git a/generic/tclTestProcBodyObj.c b/generic/tclTestProcBodyObj.c
index 1a577d9..990987f 100644
--- a/generic/tclTestProcBodyObj.c
+++ b/generic/tclTestProcBodyObj.c
@@ -20,7 +20,7 @@
* name and version of this package
*/
-static const char packageName[] = "procbodytest";
+static const char packageName[] = "tcl::procbodytest";
static const char packageVersion[] = "1.1";
/*
@@ -75,7 +75,7 @@ static const CmdTable safeCommands[] = {
*
* Procbodytest_Init --
*
* This function initializes the "procbodytest" package.
*
* Results:
* A standard Tcl result.
@@ -99,7 +99,7 @@ Procbodytest_Init(
*
* Procbodytest_SafeInit --
*
* This function initializes the "procbodytest" package.
*
* Results:
* A standard Tcl result.
@@ -315,7 +315,7 @@ ProcBodyTestProcObjCmd(
* procbodytest::check
*
* Performs an internal check that the Tcl_PkgPresent() command returns
* the same version number as was registered when the procbodytest package
* was provided. Places a boolean in the interp result indicating the
* test outcome.
*
@@ -75,7 +75,7 @@ static const CmdTable safeCommands[] = {
* Procbodytest_Init --
*
- * This function initializes the "procbodytest" package.
+ * This function initializes the "tcl::procbodytest" package.
*
* Results:
@@ -99,7 +99,7 @@ Procbodytest_Init(
* Procbodytest_SafeInit --
*
- * This function initializes the "procbodytest" package.
+ * This function initializes the "tcl::procbodytest" package.
*
* Results:
@@ -315,7 +315,7 @@ ProcBodyTestProcObjCmd(
*
* Performs an internal check that the Tcl_PkgPresent() command returns
- * the same version number as was registered when the procbodytest package
+ * the same version number as was registered when the tcl::procbodytest package
* was provided. Places a boolean in the interp result indicating the
* test outcome.